#
# spec file for package ffcall
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Only a static library is provided, so no debug information can be extracted.
%global debug_package %{nil}

# This package uses assembly to do its work.  This is the entire list of
# supported architectures understood by RPM, even those not currently supported
# by Fedora.  RPM hasn't heard about line continuations, hence the mess.
%global ffcall_arches %ix86 x86_64 %alpha %arm parisc hppa1.0 hppa1.1 hppa1.2 hppa2.0 ia64 m68k mips mipsel ppc ppc64 ppc8260 ppc8560 ppc32dy4 ppciseries ppcpseries s390 %sparc

Name:           ffcall
Version:        1.10
Release:        10.3
Summary:        Libraries for foreign function call interfaces
License:        GPL-2.0+
Group:          Development/Libraries/Other
# As this package only provides a static library together with the header files
Provides:       %{name}-devel = %version-%release
Url:            http://www.gnu.org/software/libffcall/
#
# There has been no official release for several years, and the project web
# site encourages use of a CVS snapshot.  Make the tarball as follows:
#   cvs -z3 -d:pserver:anonymous@cvs.savannah.gnu.org:/sources/libffcall 
#       export -D 2012-04-24 ffcall
#   tar cJf ffcall-20120424cvs.tar.xz ffcall
#
Source0:        ffcall-1.10+cvs20100619.tar.gz
# PATCH-EXTEND-UPSTREAM --
# This patch will not be sent upstream.  It removes the possibility of using
# mprotect() to make memory executable, as that runs afoul of SELinux.
Patch0:         %{name}-trampoline.patch
# PATCH-FIX-OPENSUSE -- There is no <asm/cachectl.h>
Patch1:         %{name}-asm_cachectl.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %{ffcall_arches}

%description
This is a collection of four libraries which can be used to build
foreign function call interfaces in embedded interpreters.  The four
packages are:
 - avcall: calling C functions with variable arguments
 - vacall: C functions accepting variable argument prototypes
 - trampoline: closures as first-class C functions
 - callback: closures with variable arguments as first-class C functions
   (a reentrant combination of vacall and trampoline)


%prep
%setup -q -n ffcall
%patch0
%patch1

# Remove prebuilt object files
find . -name \*.o | xargs rm -f

%build
export CFLAGS="$RPM_OPT_FLAGS -fPIC -DMAP_VARIABLE=MAP_PRIVATE"
%configure
make # %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_mandir}
make install DESTDIR=%{buildroot}
rm -fr %{buildroot}%{_datadir}/html
rm -f %{buildroot}%{_libdir}/*.la
cd %{buildroot}%{_mandir}/man3

# Advertise supported architectures
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cat > %{buildroot}%{_sysconfdir}/rpm/macros.ffcall << EOF
# arches that ffcall supports
%%ffcall_arches %{ffcall_arches}
EOF

# Fix man pages with overly generic names (bz 800360)
for page in *; do
  mv $page %{name}-$page
done

%files
%defattr(-,root,root,-)
%doc README NEWS COPYING
%doc avcall/avcall.html
%doc callback/callback.html
%doc callback/trampoline_r/trampoline_r.html
%doc trampoline/trampoline.html
%doc vacall/vacall.html
%{_libdir}/*.a
%{_includedir}/*
%doc %{_mandir}/man*/*
%config %{_sysconfdir}/rpm/macros.%{name}

%changelog
* Wed Feb 12 2014 ro@suse.de
- remove s390x from list of architectures (no asm code available)
* Tue May 14 2013 werner@suse.de
- Add missing BuildRoot tag
* Wed May  8 2013 werner@suse.de
- Adopt the ffcall package as provided by David Lanzendörfer, his
  version is mainly based on the Fedora ffcall package (SR#172680):
  + Wed Mar 27 2013 Jerry James <loganjerry@gmail.com> - 1.10-10.20120424cvs
  - Update to CVS 20120424
  - List all architectures supported by this package (bz 925335)
  - Rename man pages to avoid conflicts (bz 800360)
  - Add Provides: ffcall-static
  + Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10-9.20100903cvs
  - Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild
  + Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10-8.20100903cvs
  - Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild
  + Tue Jan 10 2012 Jerry James <loganjerry@gmail.com> - 1.10-7.20100903cvs
  - Clean out prebuilt object files
  - Add trampoline patch to force use of mmap() to get executable memory
  + Mon Jan  9 2012 Jerry James <loganjerry@gmail.com> - 1.10-6.20100903cvs
  - Update to CVS 20100903
  - Minor spec file cleanups
  + Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10-5.20080704cvs.1
  - Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild
  + Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10-4.20080704cvs.1
  - Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild
  + Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10-3.20080704cvs.1
  - Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild
  + Wed Dec 10 2008 Jochen Schmitt <Jochen herr-schmitt de> - 1.10-2.20080704cvs.1
  - Fix -FPIC issue (BZ #475112)
  + Fri Jul  4 2008 Gerard Milmeister <gemi@bluewin.ch> - 1.10-2.20080704cvs
  - update to cvs 20080704
  - support for ppc64
  + Mon Feb 25 2008 Gerard Milmeister <gemi@bluewin.ch> - 1.10-1
  - first Fedora release
- Correct group tag, provide ffcall-devel not ffcall-static
- Declare patch ffcall-trampoline.patch
- Add patch ffcall-asm_cachectl.patch
- Correct license string
- Declare configuration file
- Declare manual pages as documentations
